summaryrefslogtreecommitdiffstats
path: root/mdk-stage1/probing.c
diff options
context:
space:
mode:
authorThierry Vignaud <tv@mageia.org>2013-03-23 12:30:25 +0000
committerThierry Vignaud <tv@mageia.org>2013-03-23 12:30:25 +0000
commite9943abec27d5e244f3c3e86ae4905356ab67e85 (patch)
treea869517ec0b994993a7a2ba619d81de2fc72e497 /mdk-stage1/probing.c
parentb8fe5265b23376de2a40a58101188f88c0281626 (diff)
downloaddrakx-e9943abec27d5e244f3c3e86ae4905356ab67e85.tar
drakx-e9943abec27d5e244f3c3e86ae4905356ab67e85.tar.gz
drakx-e9943abec27d5e244f3c3e86ae4905356ab67e85.tar.bz2
drakx-e9943abec27d5e244f3c3e86ae4905356ab67e85.tar.xz
drakx-e9943abec27d5e244f3c3e86ae4905356ab67e85.zip
(my_insmod) rename as (my_modprobe) as it really what it is
Diffstat (limited to 'mdk-stage1/probing.c')
-rw-r--r--mdk-stage1/probing.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/mdk-stage1/probing.c b/mdk-stage1/probing.c
index 5f9983efb..224bf42ea 100644
--- a/mdk-stage1/probing.c
+++ b/mdk-stage1/probing.c
@@ -272,10 +272,10 @@ void discovered_device(enum driver_type type, const char * description, const ch
if (type == MEDIA_ADAPTERS) {
const char * alternate = NULL;
wait_message("Loading driver for media adapter:\n \n%s", description);
- failed = my_insmod(driver, MEDIA_ADAPTERS, NULL, 1);
+ failed = my_modprobe(driver, MEDIA_ADAPTERS, NULL, 1);
alternate = get_alternate_module(driver);
if (!IS_NOAUTO && alternate) {
- failed = failed || my_insmod(alternate, MEDIA_ADAPTERS, NULL, 1);
+ failed = failed || my_modprobe(alternate, MEDIA_ADAPTERS, NULL, 1);
}
remove_wait_message();
warning_insmod_failed(failed);
@@ -285,7 +285,7 @@ void discovered_device(enum driver_type type, const char * description, const ch
if (type == NETWORK_DEVICES) {
wait_message("Loading driver for network device:\n \n%s", description);
prepare_intf_descr(description);
- failed = my_insmod(driver, NETWORK_DEVICES, NULL, 1);
+ failed = my_modprobe(driver, NETWORK_DEVICES, NULL, 1);
warning_insmod_failed(failed);
remove_wait_message();
if (intf_descr_for_discover) /* for modules providing more than one net intf */
@@ -295,7 +295,7 @@ void discovered_device(enum driver_type type, const char * description, const ch
#ifdef ENABLE_USB
if (type == USB_CONTROLLERS)
/* we can't allow additional modules floppy since we need usbhid for keystrokes of usb keyboards */
- failed = my_insmod(driver, USB_CONTROLLERS, NULL, 0);
+ failed = my_modprobe(driver, USB_CONTROLLERS, NULL, 0);
#endif
}
@@ -337,7 +337,7 @@ void probe_virtio_modules(void)
if (e->vendor == VIRTIO_PCI_VENDOR) {
if (!loaded_pci) {
log_message("loading virtio-pci");
- my_insmod("virtio_pci", ANY_DRIVER_TYPE, NULL, 0);
+ my_modprobe("virtio_pci", ANY_DRIVER_TYPE, NULL, 0);
loaded_pci = 1;
}
@@ -360,7 +360,7 @@ void probe_virtio_modules(void)
}
if (name) {
log_message("virtio: loading %s", name);
- my_insmod(name, ANY_DRIVER_TYPE, options, 0);
+ my_modprobe(name, ANY_DRIVER_TYPE, options, 0);
}
}
}
@@ -431,7 +431,7 @@ void probe_that_type(enum driver_type type, enum media_bus bus __attribute__ ((u
already_mounted_usbdev = 1;
wait_message("Detecting USB devices.");
sleep(4); /* sucking background work */
- my_insmod("usbhid", ANY_DRIVER_TYPE, NULL, 0);
+ my_modprobe("usbhid", ANY_DRIVER_TYPE, NULL, 0);
remove_wait_message();
}
@@ -546,9 +546,9 @@ void probe_that_type(enum driver_type type, enum media_bus bus __attribute__ ((u
already_probed_usb_controllers && !already_loaded_usb_scsi) {
already_loaded_usb_scsi = 1;
/* we can't allow additional modules floppy since we need usbkbd for keystrokes of usb keyboards */
- my_insmod("usb_storage", MEDIA_ADAPTERS, NULL, 0);
+ my_modprobe("usb_storage", MEDIA_ADAPTERS, NULL, 0);
if (module_already_present("ieee1394"))
- my_insmod("sbp2", MEDIA_ADAPTERS, NULL, 0);
+ my_modprobe("sbp2", MEDIA_ADAPTERS, NULL, 0);
wait_message("Detecting USB mass-storage devices.");
#ifndef DEBUG
sleep(10); /* sucking background work */
@@ -960,7 +960,7 @@ char ** get_net_devices(void)
int i = 0;
if (!already_probed) {
- already_probed = 1; /* cut off loop brought by: probe_that_type => my_insmod => get_net_devices */
+ already_probed = 1; /* cut off loop brought by: probe_that_type => my_modprobe => get_net_devices */
probe_that_type(NETWORK_DEVICES, BUS_ANY);
}